@@ -131,6 +131,28 @@ describe "Cron Job" do
     end
   end
 
+  describe 'parse_enqueue_time' do
+    before do
+      @args = {
+        name: "Test",
+        cron: "* * * * *"
+      }
+      @job = Sidekiq::Cron::Job.new(@args)
+    end
+
+    it 'should correctly parse new format' do
+      assert_equal @job.send(:parse_enqueue_time, '2017-01-02 15:23:43 UTC'), Time.new(2017, 1, 2, 15, 23, 43, '+00:00')
+    end
+
+    it 'should correctly parse new format with different timezone' do
+      assert_equal @job.send(:parse_enqueue_time, '2017-01-02 15:23:43 +01:00'), Time.new(2017, 1, 2, 15, 23, 43, '+01:00')
+    end
+
+    it 'should correctly parse old format' do
+      assert_equal @job.send(:parse_enqueue_time, '2017-01-02 15:23:43'), Time.new(2017, 1, 2, 15, 23, 43, '+00:00')
+    end
+  end
+
   describe 'formatted time' do
     before do
       @args = {
@@ -201,6 +223,34 @@ describe "Cron Job" do
                                  "class"=>"CronTestClassWithQueue",
                                  "args"=>[]}
     end
+
+    it "be initialized with 'class' and date_as_argument" do
+      job = Sidekiq::Cron::Job.new('class' => 'CronTestClassWithQueue', "date_as_argument" => true)
+
+      job_message = job.message
+      job_args    = job_message.delete("args")
+      assert_equal job_message, {"retry"=>false,
+                                 "queue"=>:super,
+                                 "backtrace"=>true,
+                                 "class"=>"CronTestClassWithQueue"}
+      assert job_args[-1].is_a?(Float)
+      assert job_args[-1].between?(Time.now.to_f - 1, Time.now.to_f)
+    end
+
+    it "be initialized with 'class', 2 arguments and date_as_argument" do
+      job = Sidekiq::Cron::Job.new('class' => 'CronTestClassWithQueue', "date_as_argument" => true, "args"=> ["arg1", :arg2])
+
+      job_message = job.message
+      job_args    = job_message.delete("args")
+      assert_equal job_message, {"retry"=>false,
+                                 "queue"=>:super,
+                                 "backtrace"=>true,
+                                 "class"=>"CronTestClassWithQueue"}
+      assert job_args[-1].is_a?(Float)
+      assert job_args[-1].between?(Time.now.to_f - 1, Time.now.to_f)
+      assert_equal job_args[0..-2], ["arg1", :arg2]
+    end
+
   end
 
   describe "cron test" do
@@ -210,24 +260,24 @@ describe "Cron Job" do
 
     it "return previous minute" do
       @job.cron = "* * * * *"
-      time = Time.now.utc
+      time = Time.new(2018, 8, 10, 13, 24, 56).utc
       assert_equal @job.last_time(time).strftime("%Y-%m-%d-%H-%M-%S"), time.strftime("%Y-%m-%d-%H-%M-00")
     end
 
     it "return previous hour" do
       @job.cron = "1 * * * *"
-      time = Time.now.utc
+      time = Time.new(2018, 8, 10, 13, 24, 56).utc
       assert_equal @job.last_time(time).strftime("%Y-%m-%d-%H-%M-%S"), time.strftime("%Y-%m-%d-%H-01-00")
     end
 
     it "return previous day" do
       @job.cron = "1 2 * * * Etc/GMT"
-      time = Time.now.utc
+      time = Time.new(2018, 8, 10, 13, 24, 56).utc
 
       if time.hour >= 2
         assert_equal @job.last_time(time).strftime("%Y-%m-%d-%H-%M-%S"), time.strftime("%Y-%m-%d-02-01-00")
       else
-        yesterday = (Date.today - 1)
+        yesterday = time - 1.day
         assert_equal @job.last_time(time).strftime("%Y-%m-%d-%H-%M-%S"), yesterday.strftime("%Y-%m-%d-02-01-00")
       end
     end
@@ -299,6 +349,7 @@ describe "Cron Job" do
     it 'should return valid payload for Sidekiq::Client' do
       payload = {
         'class'       => 'ActiveJob::QueueAdapters::SidekiqAdapter::JobWrapper',
+        'wrapped'     => 'ActiveJobCronTestClass',
         'queue'       => 'super_queue',
         'description' => nil,
         'args'        => [{
@@ -330,10 +381,11 @@ describe "Cron Job" do
 
     it 'should return valid payload for Sidekiq::Client' do
       payload = {
-        'class' => 'ActiveJob::QueueAdapters::SidekiqAdapter::JobWrapper',
-        'queue' => 'prefix_super_queue',
+        'class'       => 'ActiveJob::QueueAdapters::SidekiqAdapter::JobWrapper',
+        'wrapped'     => 'ActiveJobCronTestClass',
+        'queue'       => 'prefix_super_queue',
         'description' => nil,
-        'args'  =>[{
+        'args'        => [{
           'job_class'  => 'ActiveJobCronTestClass',
           'job_id'     => 'XYZ',
           'queue_name' => 'prefix_super_queue',
@@ -357,7 +409,7 @@ describe "Cron Job" do
 
       it 'pushes to queue active jobs message' do
         @job.expects(:enqueue_active_job)
-            .returns(true)
+            .returns(ActiveJobCronTestClass.new)
         @job.enque!
       end
     end
@@ -375,7 +427,7 @@ describe "Cron Job" do
 
       it 'pushes to queue active jobs message with queue_name_prefix' do
         @job.expects(:enqueue_active_job)
-            .returns(true)
+            .returns(ActiveJobCronTestClass.new)
         @job.enque!
       end
     end
@@ -522,7 +574,6 @@ describe "Cron Job" do
       assert @job.save
     end
 
-
     it "be saved and found by name" do
       assert @job.save, "not saved"
       assert Sidekiq::Cron::Job.find("Test").is_a?(Sidekiq::Cron::Job)
@@ -599,14 +650,15 @@ describe "Cron Job" do
 
     it "last_enqueue_time shouldn't be rewritten after save" do
       #adding last_enqueue_time to initialize is only for test purpose
-      last_enqueue_time = '2013-01-01 23:59:59'
+      last_enqueue_time = '2013-01-01 23:59:59 +0000'
+      expected_enqueue_time = DateTime.parse(last_enqueue_time).to_time.utc
       Sidekiq::Cron::Job.create(@args.merge('last_enqueue_time' => last_enqueue_time))
       job = Sidekiq::Cron::Job.find(@args)
-      assert_equal job.last_enqueue_time, Time.parse(last_enqueue_time)
+      assert_equal job.last_enqueue_time, expected_enqueue_time
 
       Sidekiq::Cron::Job.create(@args)
       job = Sidekiq::Cron::Job.find(@args)
-      assert_equal job.last_enqueue_time, Time.parse(last_enqueue_time), "after second create should have same time"
+      assert_equal job.last_enqueue_time, expected_enqueue_time, "after second create should have same time"
     end
   end
 
@@ -883,7 +935,8 @@ describe "Cron Job" do
         @jobs_hash['name_of_job']['cron'] = "bad cron"
         out = Sidekiq::Cron::Job.load_from_hash @jobs_hash
         assert_equal 1, out.size, "should have 1 error"
-        assert_equal ({"name_of_job"=>["'cron' -> bad cron: not a valid cronline : 'bad cron'"]}), out
+        assert_includes out['name_of_job'].first, "bad cron"
+        assert_includes out['name_of_job'].first, "ArgumentError:"
         assert_equal 1, Sidekiq::Cron::Job.all.size, "Should have only 1 job after load"
       end
 
